function dumpNikonTagData(ifd, output, is_motorola) {
	var tagnum;
	for (var t in ifd) {
		if (t.match(/^x[0-9A-Fa-f]{4}$/)) {
			tagnum = parseInt('0' + t, 16);
			var data = ifd[t];
			switch (ifd.maker_type) {
			case 1:
				output.push(getNikonInterpretedTagDataFormat1(tagnum, data));
				break;
			case 2:
				output.push(getNikonInterpretedTagDataFormat2(tagnum, data));
				break;
			case 3:
				output.push(getNikonInterpretedTagDataFormat2(tagnum, data));
				break;
			default:
				output.push(getGenericInterpretedTagData(tagnum, data));
				break;
			}
		}
	}
}	// dumpNikonTagData()

// http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/Nikon.html
function getNikonInterpretedTagDataFormat1(tagnum, data) {
	var output = new Array();
	switch (tagnum) {
	case 0x0002:
		output.push('Version = ' + data);
		break;
	case 0x0003:
		var QualitySettings = new Array('n/a (0)', 'VGA Basic (1)', 'VGA Normal (2)', 'VGA Fine (3)', 
										'SXGA Basic (4)', 'SXGA Normal (5)', 'SXGA Fine (6)');
		output.push('Quality Setting = ' + (QualitySettings[data] ? QualitySettings[data] : data));
		break;
	case 0x0004:
		var ColourModes = new Array('n/a (0)', 'colour (1)', 'monochrome (2)');
		output.push('Colour Mode = ' + (ColourModes[data] ? ColourModes[data] : data));
		break;
	case 0x0005:
		var ImageAdjustments = new Array('normal (0)', 'bright+ (1)', 'bright- (2)', 'contrast+ (3)', 'contrast- (4)');
		output.push('Image Adjustment = ' + (ImageAdjustments[data] ? ImageAdjustments[data] : data));
		break;
	case 0x0006:
		var CCDSensitivities = new Array('ISO 80 (0)', 'n/a (1)', 'ISO 160 (2)', 'n/a (3)', 'ISO 320 (4)', 'ISO 100 (5)');
		output.push('CCD Sensitivity = ' + (CCDSensitivities[data] ? CCDSensitivities[data] : data));
		break;
	case 0x0007:
		var WhiteBalances = new Array('auto (0)', 'preset (1)', 'daylight (2)', 'incandescent (3)', 'fluorescent (4)', 
									 'cloudy (5)', 'SpeedLight (6)');
		output.push('White Balance = ' + (WhiteBalances[data] ? WhiteBalances[data] : data));
		break;
	case 0x0008:
		output.push('Focus = ' + data);
		break;
//	case 0x0009:
//		output.push('Version = ' + data);
		break;
	case 0x000A:
		output.push('Digital Zoom = ' + data);
		break;
	case 0x000B:
		var Converters = new Array('no (0)', 'yes (1)');
		output.push('Fisheye Converter = ' + (Converters[data] ? Converters[data] : data));
		break;
	default:
		output.push('Unknown (0x' + tagnum.toString(16) + ') = ' + data);
		break;
	} 
	return output.join('<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>');
}	// getNikonInterpretedTagDataFormat1()

function getNikonInterpretedTagDataFormat2(tagnum, data) {
	var output = new Array();
	switch (tagnum) {
	case 0x0001:
		output.push('Version? = ' + data);
		break;
	case 0x0002:
		var ISOSettings = new Object();
		ISOSettings['0,100'] = 'ISO 100';
		ISOSettings['0,200'] = 'ISO 200';
		ISOSettings['0,400'] = 'ISO 400';
		output.push('ISO Setting = ' + (ISOSettings[data] ? ISOSettings[data] : data));
		break;
	case 0x0003:
		output.push('Colour Mode = ' + data);
		break;
	case 0x0004:
		output.push('Quality = ' + data);
		break;
	case 0x0005:
		output.push('White Balance = ' + data);
		break;
	case 0x0006:
		output.push('Sharpness = ' + data);
		break;
	case 0x0007:
		output.push('Focus Mode = ' + data);
		break;
	case 0x0008:
		output.push('Flash Setting = ' + data);
		break;
	case 0x0009:
		output.push('Flash Type = ' + data);
		break;
	case 0x000B:
		output.push('White Balance Fine Tuning = ' + data);
		break;
	case 0x000C:
		output.push('Colour Balance 1 = ' + data);
		break;
	case 0x000D:
		output.push('Program Shift = ' + data);
		break;
	case 0x000E:
		output.push('Exposure Difference = ' + data);
		break;
	case 0x000F:
		output.push('ISO Selection = ' + data);
		break;
	case 0x0010:
		output.push('Data Dump = ' + data);
		break;
	case 0x0011:
		output.push('Nikon Preview = ' + data);
		break;
	case 0x0012:
		output.push('Flash Exposure Compensation = ' + data);
		break;
	case 0x0013:
		output.push('ISO Setting = ' + data);
		break;
	case 0x0016:
		output.push('Image Boundary = ' + data);
		break;
	case 0x0018:
		output.push('Flash Exposure Bracket Value = ' + data);
		break;
	case 0x001A:
		output.push('Image Processing = ' + data);
		break;
	case 0x001B:
		output.push('Crop High Speed = ' + data);
		break;
	case 0x001D:
		output.push('Serial Number = ' + data);
		break;
	case 0x001E:
		var ColourSpaces = new Array('n/a (0)', 'sRGB (1)', 'Adobe RGB (2)');
		output.push('Colour Space = ' + (ColourSpaces[data] ? ColourSpaces[data] : data));
		break;
	case 0x0080:
		output.push('Image Adjustment = ' + data);
		break;
	case 0x0081:
		output.push('Tone Compensation = ' + data);
		break;
	case 0x0082:
		output.push('Adapter / Auxiliary Lens = ' + data);
		break;
	case 0x0083:
		var data2 = '';
		data2 += (data & 0x01 ? 'MF ' : ''); 
		data2 += (data & 0x02 ? 'D ' : ''); 
		data2 += (data & 0x04 ? 'G ' : ''); 
		data2 += (data & 0x08 ? 'VR ' : ''); 
		output.push('Lens Type = ' + data2);
		break;
	case 0x0084:
		output.push('Lens = ' + data);
		break;
	case 0x0085:
		output.push('Manual Focus Distance = ' + data + ' m');
		break;
	case 0x0086:
		output.push('Digital Zoom = ' + data);
		break;
	case 0x0087:
		var FlashModes = new Array('did not fire (0)', 'fired, manual (1)');
		FlashModes[7] = 'fired, external (7)';
		FlashModes[8] = 'fired, commander mode (8)';
		FlashModes[9] = 'fired, TTL mode (9)';
		output.push('Flash Mode = ' + (FlashModes[data] ? FlashModes[data] : data));
		break;
	case 0x0088:
/*
		var AFFocusPositions = new Object();
		AFFocusPositions['0x00,0x00,0x00,0x00'] = 'center'; 
		AFFocusPositions['0x00,0x01,0x00,0x00'] = 'top';
		AFFocusPositions['0x00,0x02,0x00,0x00'] = 'bottom'; 
		AFFocusPositions['0x00,0x03,0x00,0x00'] = 'left';
		AFFocusPositions['0x00,0x04,0x00,0x00'] = 'right';
		output.push('AF Focus Position = ' + (AFFocusPositions[data] ? AFFocusPositions[data] : data));
*/
		var tmp = new Array();
		bytesToBuffer(data, tmp);
		var AFAreaModes = new Array('single area (0)', 'dynamic area (1)',
									'dynamic area, closest subject (2)', 'group dynamic (3)',
									'single area (wide) (4)', 'dynamic area (wide) (5)');
		output.push('AF Area Mode = ' + (AFAreaModes[tmp[0]] ? AFAreaModes[tmp[0]] : data));

		var AFPoints = new Array('center (0)', 'top (1)', 'bottom (2)', 'left (3)', 'right (4)',
								 'upper-left (5)', 'upper-right (6)', 'lower-left (7)',
								 'lower-right (8)', 'far left (9)', 'far right (10)');
		output.push('AF Point = ' + (AFPoints[tmp[1]] ? AFPoints[tmp[1]] : data));
		
		var data2 = '';
		data2 += (tmp[2] & 0x001 ? 'center ' : ''); 
		data2 += (tmp[2] & 0x002 ? 'top ' : ''); 
		data2 += (tmp[2] & 0x004 ? 'bottom ' : ''); 
		data2 += (tmp[2] & 0x008 ? 'left ' : ''); 
		data2 += (tmp[2] & 0x010 ? 'right ' : ''); 
		data2 += (tmp[2] & 0x020 ? 'upper-left ' : ''); 
		data2 += (tmp[2] & 0x040 ? 'upper-right ' : ''); 
		data2 += (tmp[2] & 0x080 ? 'lower-left ' : ''); 
		data2 += (tmp[2] & 0x100 ? 'lower-right ' : ''); 
		data2 += (tmp[2] & 0x200 ? 'far-left ' : ''); 
		data2 += (tmp[2] & 0x400 ? 'far-right ' : ''); 
		output.push('AF Points Used = ' + data2); 

		break;
	case 0x0089:
		var data2 = '';
		data2 += (data & 0x01 ? 'continuous ' : ''); 
		data2 += (data & 0x02 ? 'delay ' : ''); 
		data2 += (data & 0x04 ? 'PC-control ' : ''); 
		data2 += (data & 0x08 ? '? ' : ''); 
		data2 += (data & 0x10 ? 'exposure-bracketing ' : ''); 
		data2 += (data & 0x20 ? 'unused-LE-NR-slowdown ' : ''); 
		data2 += (data & 0x40 ? 'white-balance-bracketing ' : ''); 
		data2 += (data & 0x80 ? 'IR-control ' : ''); 
		output.push('Shooting Mode = ' + data2);
		break;
	case 0x008A:
		var AutoBracketReleases = new Array('none (0)', 'auto release (1)', 'manual relase (2)');
		output.push('Auto Bracket Release = ' + (AutoBracketReleases[data] ? AutoBracketReleases[data] : data));
		break;
	case 0x008B:
		output.push('Lens F-Stops = ' + data);
		break;
	case 0x008C:
		output.push('NEF Curve 1 = ' + data);
		break;
	case 0x008D:
		output.push('Colour Hue = ' + data);
		break;
	case 0x008F:
		output.push('Scene Mode = ' + data);
		break;
	case 0x0090:
		output.push('Light Source = ' + data);
		break;
	case 0x0092:
		output.push('Hue Adjustment = ' + data);
		break;
	case 0x0094:
		output.push('Saturation = ' + data);
		break;
	case 0x0095:
		output.push('Noise Reduction = ' + data);
		break;
	case 0x0096:
		output.push('NEF Curve 2 = ' + data);
		break;
	case 0x0097:
		output.push('Colour Balance = ' + data);
		break;
	case 0x0098:
		output.push('Lens Data = ' + data);
		break;
	case 0x0099:
		output.push('Raw Image Center = ' + data);
		break;
	case 0x009A:
		output.push('Sensor Pixel Size = ' + data);
		break;
	case 0x00A0:
		output.push('Serial Number = ' + data);
		break;
	case 0x00A2:
		output.push('Image Data Size = ' + data);
		break;
	case 0x00A5:
		output.push('Image Count = ' + data);
		break;
	case 0x00A6:
		output.push('Deleted Image Count = ' + data);
		break;
	case 0x00A7:
		output.push('Shutter Count = ' + data);
		break;
	case 0x00A9:
		output.push('Image Optimization = ' + data);
		break;
	case 0x00AA:
		output.push('Saturation = ' + data);
		break;
 	 	string 	 
	case 0x00AB:
		output.push('Vari Program = ' + data);
		break;
	case 0x00AC:
		output.push('Image Stabilization = ' + data);
		break;
	case 0x00AD:
		output.push('AF Response = ' + data);
		break;
	case 0x00B1:
		var NoiseReductions = new Array('off (0)', 'on for ISO 1600/3200 (1)', 'weak (2)',
										'n/a (3)', 'normal (4)', 'n/a (5)', 'strong (6)');
		output.push('High ISO Noise Reduction = ' + (NoiseReductions[data] ? NoiseReductions[data] : data));
		break;
	case 0x0E00:
		output.push('Print IM = ' + data);
		break;
	case 0x0E01:
		output.push('Nikon Capture Data = ' + data);
		break;
	case 0x0E09:
		output.push('Nikon Capture Version = ' + data);
		break;
	case 0x0E0E:
		output.push('Nikon Capture Offsets = ' + data);
		break;
	default:
		output.push('Unknown (0x' + tagnum.toString(16) + ') = ' + data);
		break;
	} 
	return output.join('<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>');
}	// getNikonInterpretedTagDataFormat2()

function getNikonInterpretedTagData3(tagnum, data) {
	var output = new Array();
	switch (tagnum) {
	default:
		output.push('Unknown (0x' + tagnum.toString(16) + ') = ' + data);
		break;
	} 
	return output.join('<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>');
}	// getNikonInterpretedTagData3()
