// may also apply for Leica

function dumpPanasonicTagData(ifd, output, is_motorola) {
	var tagnum;
	for (var t in ifd) {
		if (t.match(/^x[0-9A-Fa-f]{4}$/)) {
			tagnum = parseInt('0' + t, 16);
			var data = ifd[t];
			output.push(getPanasonicInterpretedTagData1(tagnum, data));
		}
	}
}	// dumpPanasonicTagData()

// http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/Panasonic.html
function getPanasonicInterpretedTagData1(tagnum, data) {
	var output = new Array();
	switch (tagnum) {
	case 0x0001:
		var ImageQualities = new Array('n/a (0)', 'n/a (1)', 'high (2)', 'normal (3)',
									   'n/a (4)', 'n/a (5)', 'very high (6)', 'raw (7)');
		output.push('Image Quality = ' + (ImageQualities[data] ? ImageQualities[data] : data));
		break;
	case 0x0002:
		output.push('Firmware Version = ' + data);
		break;
	case 0x0003:
		var WhiteBalances = new Array('n/a (0)', 'auto (1)', 'daylight (2)', 'cloudy (3)', 'halogen (4)',
									  'manual (5)', 'n/a (6)', 'n/a (7)', 'flash (8)', 'n/a (9)',
									  'black &amp; white (10)');
		output.push('White Balance = ' + (WhiteBalances[data] ? WhiteBalances[data] : data));
		break;
	case 0x0007:
		var FocusModes = new Array('n/a (0)', 'auto (1)', 'manual (2)', 'n/a (3)', 'auto, focus button (4)',
								   'auto, continuous (5)');
		output.push('Focus Mode = ' + (FocusModes[data] ? FocusModes[data] : data));
		break;
	case 0x000F:
		var SpotModes = new Object();
		SpotModes['0x00,0x01'] = 'off';
		SpotModes['0x00,0x10'] = 'on';
		output.push('Spot Mode = ' + (SpotModes[data] ? SpotModes[data] : data));
		break;
	case 0x001A:
		var ImageStabilizers = new Array('n/a (0)', 'n/a (1)', 'on, mode 1 (2)', 'off (3)',
										 'on, mode 2 (4)');
		output.push('Image Stabilizer = ' + (ImageStabilizers[data] ? ImageStabilizers[data] : data));
		break;
	case 0x001C:
		var MacroModes = new Array('n/a (0)', 'on (1)', 'off (2)');
		MacroModes[257] = 'tele-macro';
		output.push('Macro Mode = ' + (MacroModes[data] ? MacroModes[data] : data));
		break;
	case 0x001F:
		var ShootingModes = new Array('n/a (0)', 'normal (1)', 'portrait (2)', 'scenery (3)',
									  'sports (4)', 'night portrait (5)', 'program (6)',
									  'aperture priority (7)', 'shutter priority (8)', 'macro (9)',
									  'n/a (10)', 'manual (11)', 'n/a (12)', 'panning (13)', 'n/a (14)',
									  'n/a (15)', 'n/a (16)', 'n/a (17)', 'fireworks (18)', 'party (19)',
									  'snow (20)', 'night scenery (21)', 'food (22)');
		output.push('Shooting Mode = ' + (ShootingModes[data] ? ShootingModes[data] : data));
		break;
	case 0x0020:
		var Audios = new Array('n/a (0)', 'yes (1)', 'no (2)');
		output.push('Audio = ' + (Audios[data] ? Audios[data] : data));
		break;
	case 0x0021:
		output.push('Data Dump = ' + data);
		break;
	case 0x0023:
		output.push('White Balance Bias = ' + data);
		break;
	case 0x0024:
		output.push('Flash Bias = ' + data);
		break;
	case 0x0025:
		output.push('Internal Serial Number = ' + data);
		break;
	case 0x0028:
		var ColourEffects = new Array('n/a (0)', 'off (1)', 'warm (2)', 'cool (3)',
									 'black &amp; white (4)', 'sepia (5)');
		output.push('Colour Effect = ' + (ColourEffects[data] ? ColourEffects[data] : data));
		break;
	case 0x002A:
		var BurstModes = new Array('off (0)', 'low/high quality (1)', 'infinite (2)');
		output.push('Burst Mode = ' + (BurstModes[data] ? BurstModes[data] : data));
		break;
	case 0x002B:
		output.push('Sequence Number = ' + data);
		break;
	case 0x002C:
		var Contrasts = new Array('normal [Panasonic] (0)', 'low [Panasonic] (1)', 'high [Panasonic] (2)');
		Contrasts[0x100] = 'low [Leica] (0x100)';
		Contrasts[0x110] = 'normal [Leica] (0x110)';
		Contrasts[0x120] = 'high [Leica] (0x120)';
		output.push('Contrast = ' + (Contrasts[data] ? Contrasts[data] : data));
		break;
	case 0x002D:
		var NoiseReductions = new Array('standard (0)', 'low (1)', 'high (2)');
		output.push('Noise Reduction = ' + (NoiseReductions[data] ? NoiseReductions[data] : data));
		break;
	case 0x002E:
		var SelfTimers = new Array('n/a (0)', 'off (1)', '10s (2)', '2s (3)');
		output.push('Self Timer = ' + (SelfTimers[data] ? SelfTimers[data] : data));
		break;
	case 0x0030:
		var Rotations = new Array('n/a (0)', 'horizontal (normal) (1)', 'n/a (2)', 'n/a (3)',
								  'n/a (4)', 'n/a (5)', 'rotate 90 CW (6)', 'n/a (7)',
								  'rotate 270 CW (8)');
		output.push('Rotation = ' + (Rotations[data] ? Rotations[data] : data));
		break;
	case 0x0032:
		var ColourModes = new Array('normal (0)', 'natural (1)');
		output.push('Colour Mode = ' + (ColourModes[data] ? ColourModes[data] : data));
		break;
	case 0x0036:
		output.push('Travel Day = ' + data);
		break;
	case 0x0E00:
		output.push('Print IM = ' + data);
		break;
	default:
		output.push('Unknown (0x' + tagnum.toString(16) + ') = ' + data);
		break;
	} 
	return output.join('<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>');
}	// getPanasonicInterpretedTagData()
