// Exif 2.2
function getExifInterpretedTagData(tagnum, data, dtype) {
	var output = '';
			switch (tagnum) {
			case 0x0000:	// GPSVersionID (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Version ID = ' + data;
				} else {
					output = '? = ' + data;
				}
				break;			
			case 0x0001:	// InteroperabilityIndex (Iop IFD), GPSLatitudeRef (GPS IFD) 
				if (dtype == 'GPS') {
					output = 'GPS Latitude Reference = ' + data;	// North or South latitude
				} else { 
					output = 'Interoperability Index = ' + data;
				}
				break;
			case 0x0002:	// (Iop IFD?), GPSLatitude (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Latitude = ' + data + ' [degrees, minutes, seconds] ===> ' + formatLatLong(data, 5);
				} else {
					output = 'Interoperability Version = ' + bytesToString(data);
				}
				break;
			case 0x0003:	// GPSLongitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Longitude Reference = ' + data;	// East or West
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0004:	// GPSLongitude (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Longitude  = ' + data + ' [degrees, minutes, seconds] ===> ' + formatLatLong(data, 5);
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0005:	// GPSAltitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Altitude Reference  = ' + (data == 0 ? 'sea level' : 'sea level reference (negative value)');
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0006:	// GPSAltitude (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Altitude  = ' + data + ' m = ' + formatRational(data, 2) + ' m';
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0007:	// GPSTimeStamp (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Time Stamp / UTC Time = ' + data + ' [hours, minutes, seconds] ===> ' + formatTimestamp(data, 2);
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0008:	// GPSSatellites (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Satellites = ' + data;
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0009:	// GPSStatus (GPS IFD)
				if (dtype == 'GPS') {
					var GPSStatuses = new Object();
					GPSStatuses.A = 'measurement in progress';
					GPSStatuses.V = 'measurement interoperability';
					output = ' = ' + GPSStatuses[data];
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x000A:	// GPSMeasureMode (GPS IFD)
				if (dtype == 'GPS') {
					var GPSMeasureModes = new Array('n/a', '2-dimensional (1)', '3-dimensional (2)');
					output = 'GPS Measure Mode = ' + GPSMeasureModes[data];
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x000B:	// GPSDOP (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Data Degree of Precision (DOP) = ' + data;
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x000C:	// GPSSpeedRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSSpeedRefs = new Object();
					GPSSpeedRefs.K = 'kilometers per hour';
					GPSSpeedRefs.M = 'miles per hour';
					GPSSpeedRefs.N = 'knots';
					output = 'GPS Speed Reference  = ' + GPSSpeedRefs[data];
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x000D:	// GPSSpeed (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Speed = ' + data + ' = ' + formatRational(data, 2);
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x000E:	// GPSTrackRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSTrackRefs = new Object();
					GPSTrackRefs.T = 'true direction';
					GPSTrackRefs.M = 'magnetic direction';
					output = 'GPS Track Reference = ' + GPSTrackRefs[data];
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x000F:	// GPSTrack (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Track Direction = ' + data + ' degrees';
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0010:	// GPSImgDirectionRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSImgDirectionRefs = new Object();
					GPSImgDirectionRefs.T = 'true direction';
					GPSImgDirectionRefs.M = 'magnetic direction';
					output = 'GPS Image Direction Reference = ' + GPSImgDirectionRef[data];
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0011:	// GPSImgDirection (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Image Direction = ' + data + ' degrees';
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0012:	// GPSMapDatum (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Map Datum = ' + data;
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0013:	// GPSDestLatitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Destination Latitude Reference  = ' + data;	// North or South
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0014:	// GPSDestLatitude (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Destination Latitude  = ' + data + ' [degrees, minutes, seconds] ===> ' + formatLatLong(data, 5);
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0015:	// GPSDestLongitudeRef (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Destination Longitude Reference  = ' + data; // East or West
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0016:	// GPSDestLongitude (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Destination Longitude  = ' + data + ' [degrees, minutes, seconds] ===> ' + formatLatLong(data, 5);
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0017:	// GPSDestBearingRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSDestBearingRefs = new Object();
					GPSDestBearingRefs.T = 'true direction';
					GPSDestBearingRefs.M = 'magnetic direction';
					output = 'GPS Destination Bearing Reference  = ' + GPSDestBearingRefs[data];
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0018:	// GPSDestBearing (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Destination Bearing  = ' + data + ' degrees';
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x0019:	// GPSDestDistanceRef (GPS IFD)
				if (dtype == 'GPS') {
					var GPSDestDistanceRefs = new Object();
					GPSDestDistanceRefs.K = 'kilometers';
					GPSDestDistanceRefs.M = 'miles';
					GPSDestDistanceRefs.N = 'knots';
					output = 'GPS Destination Distance Reference = ' + GPSDestDistanceRefs[data];
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x001A:	// GPSDestDistance (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Destination Distance = ' + data;
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x001B:	// GPSProcessingMethod (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Processing Method = ' + data;
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x001C:	// GPSAreaInformation (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Area Information  = ' + data;
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x001D:	// GPSDateStamp (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Date Stamp = ' + data + ' UTC';
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x001E:	// GPSDifferential (GPS IFD)
				if (dtype == 'GPS') {
					output = 'GPS Differential  = ' + (data == 0 ? 'no differential correction (0)' : 'differential correction applied (1)');
				} else {
					output = '? = ' + data;
				}
				break;
			case 0x00FE:	// (Iop IFD?)
				output = 'New Subfile Type = ' + data;
				break; 	
			case 0x00FF:	// (Iop IFD?)
				output = 'Subfile Type = ' + data;
				break;
			case 0x0100:	// ImageWidth
				output = 'Image Width = ' + data + ' pixels';
				break;
			case 0x0101:	// ImageLength
				output = 'Image Length = ' + data + ' pixels';
				break;
			case 0x0102:	// BitsPerSample  
				output = 'Bits Per Sample  = ' + data;
				break;
			case 0x0103:	// Compression
				var Compressions = new Array('n/a', 'uncompressed (1)', 'n/a', 'n/a', 'n/a', 'n/a', 'JPEG compression (6)');
				output = 'Compression = ' + Compressions[data];
				break;
			case 0x0106:	// PhotometricInterpretation 
				var PhotometricInterpretations = new Array('n/a', 'n/a', 'RGB (2)', 'n/a', 'n/a', 'n/a', 'YCbCr (6)');
				output = 'Photometric Interpretation  = ' + PhotometricInterpretations[data];
				break;
			case 0x010E:	// ImageDescription 
				output = 'Image Description = ' + data;
				break;
			case 0x010F:	// Make
				output = 'Camera Make = ' + data;
				break;
			case 0x0110:	// Model
				output = 'Camera Model = ' + data;
				break;
			case 0x0111:	// StripOffsets
				output = 'Strip Offsets = ' + data;
				break;
			case 0x0112:	// Orientation 
				var orientationFlags = new Array('undefined (0)', 'normal (1)', 'flipped horizontal (2)', 
								 'rotated 180&#176; (3)', 'flipped vertical (4)',
								 'transposed (5)', 'rotated 90&#176; (6)', 'transversed (7)',
								 'rotated 270&#176; (8)');   
				output = 'Picture Orientation = ' + (data >= 0 &&  data <= 8 ? orientationFlags[data] : '(Invalid value)');
				break;
			case 0x0115:	// SamplesPerPixel 
				output = 'Samples Per Pixel  = ' + data;
				break;
			case 0x0116:	// RowsPerStrip 
				output = 'Rows Per Strip  = ' + data;
				break;
			case 0x0117:	// StripByteCounts 
				output = 'Strip Byte Counts  = ' + data;
				break;
			case 0x011A:	// XResolution
				output = 'X-Resolution = ' + data + ' = ' + formatRational(data, 2);
				break;
			case 0x011B:	// YResolution
				output = 'Y-Resolution = ' + data + ' = ' + formatRational(data, 2);
				break;
			case 0x011C:	// PlanarConfiguration
				var PlanarConfigurations = new Array('n/a', 'chunky format (1)', 'planar format (2)');
				output = 'Planar Configuration = ' + PlanarConfigurations[data];
				break;
			case 0x0128:	// ResolutionUnit 
				var ResolutionUnits = new Array('n/a (0)', 'none (1)', 'inch (2)', 'cm (3)');
				output = 'X/Y-Resolution Unit = ' + ResolutionUnits[data];
				break;
			case 0x012D:	// TransferFunction 
				output = 'Transfer Function = ' + data;
				break; 	
			case 0x0131:	// Software
				output = 'Software/Firmware Version = ' + data;
				break;
			case 0x0132:	// DateTime
				output = 'Last Modified Date/Time = ' + data;
				break;
			case 0x013B:	// Artist
				output = 'Artist = ' + data;
				break;	
			case 0x013D:	// (Not in Exif 2.2 specifications)
				output = 'Predictor = ' + data;
				break; 	
			case 0x013E:	// WhitePoint 
				output = 'White Point Chromaticity = ' + data + ' = ' + formatRationals(data, 3);
				break;
			case 0x013F:	// PrimaryChromaticities
				output = 'Primary Chromaticities = ' + data + ' = ' + formatRationals(data, 2);
				break;
			case 0x0142:	// (Not in Exif 2.2 specifications)
				output = 'Tile Width = ' + data;
				break; 	
			case 0x0143:	// (Not in Exif 2.2 specifications)
				output = 'Tile Length = ' + data;
				break; 	
			case 0x0144:	// (Not in Exif 2.2 specifications)
				output = 'Tile Offsets = ' + data;
				break;	
			case 0x0145:	// (Not in Exif 2.2 specifications)
				output = 'Tile Byte Counts = ' + data;
				break;	
			case 0x014A:	// (Not in Exif 2.2 specifications)
				output = 'Sub IFDs = ' + data;
				break;	
			case 0x015B:	// (Not in Exif 2.2 specifications)
				output = 'JPEG Tables = ' + data;
				break;	
			case 0x0201:	// JPEGInterchangeFormat 
				output = 'Offset to the start byte (SOI) of JPEG compressed thumbnail data = ' + data;
				break;
			case 0x0202:	// JPEGInterchangeFormatLength
				output = 'JPEG Interchange Format Length = ' + data;
				break;
			case 0x0211:	// YCbCrCoefficients 
				output = 'Y/Cb/Cr Coefficients = ' + data + ' = ' + formatRationals(data, 3);
				break;
			case 0x0212:	// YCbCrSubSampling 
				// 2,1 = YCbCr4:2:2 
				// 2,2 = YCbCr4:2:0 
				output = 'YCbCrSubSampling  = ' + data;
				break;
			case 0x0213:	// YCbCrPositioning
				var YCbCrPos = new Array('n/a', 'centered / center of pixel array (1)', 'co-sited / datum point (2)');
				output = 'Y/Cb/Cr Positioning (Subsampling) = ' + YCbCrPos[data];
				break;
			case 0x0214:	// ReferenceBlackWhite 
				output = 'Reference Value of Black/White Point = ' + data;
				break;
			case 0x1000:	// (Not in Exif 2.2 specifications)
				output = 'Related Image File Format = ' + data;
				break;
			case 0x1001:	// (Not in Exif 2.2 specifications)
				output = 'Related Image Width = ' + data;
				break;
			case 0x1002:	// (Not in Exif 2.2 specifications)
				output = 'Related Image Length = ' + data;
				break;
			case 0x828D:	// (Not in Exif 2.2 specifications)
				output = 'CFA Repeat Pattern Dimension = ' + data;
				break; 	
			case 0x828E:	// (Not in Exif 2.2 specifications)
				output = 'CFA Pattern = ' + data;
				break;	
			case 0x828F:	// (Not in Exif 2.2 specifications)
				output = 'Battery Level = ' + data;
				break; 	
			case 0x8298:	// Copyright (Exif IFD)
				output = 'Copyright Owner = ' + data;
				break;
			case 0x829A:	// ExposureTime (Exif IFD)
				output = 'Exposure Time (1 / Shutter Speed) = ' + data + ' second' + ' = ' + formatRational(data, 5) + ' second';
				break;
			case 0x829D:	// FNumber (Exif IFD)
				output = 'Lens F-Number/F-Stop = ' + data + ' = F' + formatRational(data, 2);
				break;
			case 0x83BB:	// (Not in Exif 2.2 specifications)
				output = 'IPTC/NAA = ' + data;
				break;	
			case 0x8773:	// (Not in Exif 2.2 specifications)
				output = 'Inter Color Profile = ' + data;
				break;	
			case 0x8822:	// ExposureProgram (Exif IFD)
				var ExpProgs = new Array('n/a', 'manual control (1)', 'normal program (2)', 'aperture priority (3)', 
										 'shutter priority (4)', 'creative program (slow program, depth of field) (5)', 
										 'action program (high-speed program, fast shutter speed) (6)', 'portrait mode (7)', 
										 'landscape mode (8)');
				output = 'Exposure Program = ' + ExpProgs[data];
				break;
			case 0x8824:	// SpectralSensitivity (Exif IFD)
				output = 'Spectral Sensitivity = ' + data;
				break;	
			case 0x8827:	// ISOSpeedRatings (Exif IFD)
				output = 'ISO Speed Ratings = ' + data;
				break;
			case 0x8828:	// OECF (Exif IFD)
				// similar to 0xA302
				output = 'Opto-Electric Conversion Function (OECF) = ' + data;
				break;	
			case 0x8829:	// (Not in Exif 2.2 specifications)
				output = 'Interlace = ' + data;
				break; 	
			case 0x882A:	// (Not in Exif 2.2 specifications)
				output = 'Time Zone Offset = ' + data;
				break; 	
			case 0x882B:	// (Not in Exif 2.2 specifications)
				output = 'Self Timer Mode = ' + data;
				break; 	
			case 0x9000:	// ExifVersion (Exif IFD)
				output = 'Exif Version = ' + bytesToString(data);
				break;
			case 0x9003:	// DateTimeOriginal (Exif IFD)
				output = 'Original Date/Time = ' + data;
				break;
			case 0x9004:	// DateTimeDigitized (Exif IFD)
				output = 'Digitization Date/Time = ' + data;
				break;
			case 0x9101:	// ComponentsConfiguration (Exif IFD)
				output = 'Components Configuration = ' + data + ' / '
								+ data.replace(/0x01/g, 'Y').replace(/0x02/g, 'Cb').replace(/0x03/g, 'Cr')
									  .replace(/0x04/g, 'R').replace(/0x05/g, 'G').replace(/0x06/g, 'B')
									  .replace(/0x00/g, '').replace(/,/g, '');
				break;
			case 0x9102:	// (Not in Exif 2.2 specifications)
				output = 'Compressed Bits per Pixel = ' + data + ' = ' + formatRational(data, 2);
				break;
			case 0x9201:	// ShutterSpeedValue (Exif IFD)
				var tmp = data.split('/');
				output = 'Shutter Speed Value (APEX) = ' + data + '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>'
						 + 'Shutter Speed (Exposure Time) = 1/' + roundValue(Math.pow(2, tmp[0]/tmp[1]), 2) + ' second';
				break;
			case 0x9202:	// ApertureValue (Exif IFD)
				var tmp = data.split('/');
				output = 'Aperture Value (APEX) = ' + data + '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>'
						 + 'Aperture = F' + roundValue(Math.pow(2, tmp[0]/tmp[1]/2), 2);
				break;
			case 0x9203:	// BrightnessValue (Exif IFD)
				var tmp = data.split('/');
				output = 'Brightness (APEX) = ' + data + '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>'
						 + 'Brightness = ' + roundValue(Math.pow(2, tmp[0]/tmp[1]), 2) + ' foot-lambert';
				break;
			case 0x9204:	// ExposureBiasValue (Exif IFD)
				output = 'Exposure Bias (EV) = ' + data + ' = ' + formatRational(data, 2);
				break;
			case 0x9205:	// MaxApertureValue (Exif IFD)
				var tmp = data.split('/');
				output = 'Max Aperture Value (APEX) = ' + data + ' = ' + formatRational(data, 2) + '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>'
						 + 'Max Aperture = F' + roundValue(Math.pow(2, tmp[0]/tmp[1]/2), 2);
				break;
			case 0x9206:	// SubjectDistance (Exif IFD)
				output = 'Distance to Subject = ' + data + ' m';
				break;
			case 0x9207:	// MeteringMode (Exif IFD)
				var MeteringModes = new Array('unknown (0)', 'average (1)', 'center weighted average (2)', 
									'spot (3)', 'multi-spot (4)', 'pattern / multi-segment (5)', 'partial (6)');
				MeteringModes[255] = 'other (255)';
				output = 'Metering Mode = ' + (MeteringModes[data] ? MeteringModes[data] : 'n/a (' + data + ')');
				break;
			case 0x9208:	// LightSource (Exif IFD)
				var LightSources = new Array('unknown (0)', 'daylight (1)', 'fluorescent (2)', 
											 'tungsten / incandescent (3)', 'flash (4)',
											 'n/a (5)', 'n/a (6)', 'n/a (7)', 'n/a (8)', 
											 'fine weather (9)', 'cloudy weather (10)', 'shade(11)', 
											 'daylight fluorescent (12)', 'day white fluorescent (13)',
											 'cool white fluorescent (14)', 'white fluorescent (15)',
											 'n/a (16)', 'standard light A (17)', 'standard light B (18)',
											 'standard light C (19)', 'D55 (20)', 'D65 (21)',
											 'D75 (22)', 'D50 (23)', 'ISO studio tungsten (24)');
				LightSources[255] = 'other (255)';
				output = 'Light Source / White Balance = ' + LightSources[data];
				break;
			case 0x9209:	// Flash (Exif IFD)
				var Flashes = new Array();
				Flashes[0x0000] = 'Flash did not fire'; 
				Flashes[0x0001] = 'Flash fired';
				Flashes[0x0005] = 'Strobe return light not detected'; 
				Flashes[0x0007] = 'Strobe return light detected';
				Flashes[0x0009] = 'Flash fired, compulsory flash mode';
				Flashes[0x000D] = 'Flash fired, compulsory flash mode, return light not detected'; 
				Flashes[0x000F] = 'Flash fired, compulsory flash mode, return light detected'; 
				Flashes[0x0010] = 'Flash did not fire, compulsory flash mode'; 
				Flashes[0x0018] = 'Flash did not fire, auto mode';
				Flashes[0x0019] = 'Flash fired, auto mode';
				Flashes[0x001D] = 'Flash fired, auto mode, return light not detected'; 
				Flashes[0x001F] = 'Flash fired, auto mode, return light detected'; 
				Flashes[0x0020] = 'No flash function';
				Flashes[0x0041] = 'Flash fired, red-eye reduction mode';
				Flashes[0x0045] = 'Flash fired, red-eye reduction mode, return light not detected';
				Flashes[0x0047] = 'Flash fired, red-eye reduction mode, return light detected';
				Flashes[0x0049] = 'Flash fired, compulsory flash mode, red-eye reduction mode';
				Flashes[0x004D] = 'Flash fired, compulsory flash mode, red-eye reduction mode, return light not detected'; 
				Flashes[0x004F] = 'Flash fired, compulsory flash mode, red-eye reduction mode, return light detected'; 
				Flashes[0x0059] = 'Flash fired, auto mode, red-eye reduction mode';
				Flashes[0x005D] = 'Flash fired, auto mode, return light not detected, red-eye reduction mode'; 
				Flashes[0x005F] = 'Flash fired, auto mode, return light detected, red-eye reduction mode'; 				
//								'flash did not fire (0)', 'flash fired (1)', 'n/a (2)',
//								'n/a (3)', 'n/a (4)', 'flash fired but strobe return light not detected (5)', 
//								'n/a (6)', 'flash fired and strobe return light detected (7)');
				Flashes[255] = 'other (255)';
				output = 'Flash = ' + (Flashes[data] ? Flashes[data] : 'n/a (' + data + ')');
				break;
			case 0x920A:	// FocalLength (Exif IFD)
				output = 'Focal Length = ' + data + ' mm = ' + formatRational(data, 2) + ' mm';
				break;
			case 0x920B:	// FlashEnergy (Exif IFD) ???
				output = 'Flash/Strobe Energy = ' + data + ' BCPS';
				break; 	
			case 0x920C:	// (Not in Exif 2.2 specifications)
				output = 'Spatial Frequency Response = ' + data;
				break;	
			case 0x920D:	// (Not in Exif 2.2 specifications)
				output = 'Noise = ' + data;
				break;	
			case 0x9211:	// (Not in Exif 2.2 specifications)
				output = 'Image Number = ' + data;
				break; 	
			case 0x9212:	// (Not in Exif 2.2 specifications)
				output = 'Security Classification = ' + data;
				break; 	
			case 0x9213:	// (Not in Exif 2.2 specifications)
				output = 'Image History = ' + data;
				break;	
			case 0x9214:	// SubjectArea (Exif IFD) 
				var tmp = data.split(',');
				var Counts = new Array('n/a', 'n/a', 'x/y coordinates of main subject',
							'x/y coordinates of center and radius of circle', 
							'x/y coordinates of center and width/height of rectangle');
				output = 'Subject Location = ' + data + ' ' + Counts[tmp.length];
				break; 	
			case 0x9215:	// (Not in Exif 2.2 specifications)
				output = 'Exposure Index = ' + data;
				break; 	
			case 0x9216:	// (Not in Exif 2.2 specifications)
				output = 'TIFF/EP Standard ID = ' + data;
				break; 	
			case 0x927C:	// MakerNote (Exif IFD)
				output = 'Maker Note = ' + data;
				break;
			case 0x9286:	// UserComment (Exif IFD)
				var char_code = 'unknown';
				if (data.indexOf('0x41,0x53,0x43,0x49,0x49,0x00,0x00,0x00') == 0) {
					char_code = 'ASCII';
				} else if (data.indexOf('0x4a,0x49,0x53,0x00,0x00,0x00,0x00,0x00') == 0) {
					char_code = 'JIS';
				} else if (data.indexOf('0x55,0x4e,0x49,0x43,0x4f,0x44,0x45,0x00') == 0) {
					char_code = 'Unicode';
				} else if (data.indexOf('0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00') == 0) {
					char_code = 'not defined';
				}
				output = 'User Comment (Hex) = ' + data + '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>'
						 + 'User Comment Character Code = ' + char_code;
				if (char_code == 'ASCII') {
					output += '<' + exifasr_xml0 + 'br' + exifasr_xml1 + '>User Comment = ' + bytesToString(data.substr(8*5));
				}
				break;
			case 0x9290:	// SubsecTime (Exif IFD)
				output = 'Last Modified Subsecond Time = ' + data;
				break;
			case 0x9291:	// SubsecTimeOriginal (Exif IFD)
				output = 'Original Subsecond Time = ' + data;
				break;
			case 0x9292:	// SubsecTimeDigitized (Exif IFD)
				output = 'Digitized Subsecond Time = ' + data;
				break;
			case 0xA000:	// FlashpixVersion (Exif IFD)
				output = 'FlashPix Version = ' + bytesToString(data);
				break;
			case 0xA001:	// ColorSpace (Exif IFD)
				var ColorSpaces = new Array();
				ColorSpaces[1] = 'sRGB (1)';
				ColorSpaces[255] = 'uncalibrated (255)';
				output = 'Color Space = ' + (ColorSpaces[data] ? ColorSpaces[data] : data);
				break;
			case 0xA002:	// PixelXDimension (Exif IFD)
				output = 'Image Width = ' + data;
				break;
			case 0xA003:	// PixelYDimension (Exif IFD)
				output = 'Image Height = ' + data;
				break;
			case 0xA004:	// RelatedSoundFile (Exif IFD)
				output = 'Related Sound File = ' + data;
				break;
			case 0xA20B:	// FlashEnergy (Exif IFD)
				output = 'Flash/Strobe Energy = ' + data + ' BCPS';
				break; 	
			case 0xA20C:	// SpatialFrequencyResponse (Exif IFD)
				// like 0xA302
				output = 'Spatial Frequency Response = ' + data;
				break; 	
			case 0xA20E:	// FocalPlaneXResolution (Exif IFD)
				output = 'Focal Plane X-Resolution = ' + data + ' = ' + formatRational(data, 2);
				break; 
			case 0xA20F:	// FocalPlaneYResolution (Exif IFD)
				output = 'Focal Plane Y-Resolution = ' + data + ' = ' + formatRational(data, 2);
				break;
			case 0xA210:	// FocalPlaneResolutionUnit (Exif IFD)
				var FPUnits = new Array('n/a (0)', 'none (1)', 'inch (2)', 'centimeter (3)'); 
				output = 'Focal Plane X/Y-Resolution Unit = ' + FPUnits[data];
				break;
			case 0xA214:	// SubjectLocation (Exif IFD)
				output = 'Subject Location = ' + data + ' [x/y-coordinates]';
				break;
			case 0xA215:	// ExposureIndex (Exif IFD)
				output = 'Exposure Index = ' + data;
				break;
			case 0xA217:	// SensingMethod (Exif IFD)
				var SensingMethods = new Array('n/a', 'n/a (1)', 'one-chip color area sensor (2)',
									 'two-chip color area sensor (3)', 'three-chip color area sensor (4)',
									 'color sequential area sensor (5)', 'n/a', 'trilinear sensor (7)',
									 'color sequential linear sensor (8)');
				output = 'Image Sensing Method = ' + SensingMethods[data];
				break;
			case 0xA300:	// FileSource (Exif IFD)
				output = 'Image Source = ' + (data == '0x03,0x00,0x00,0x00' ? 'digital still camera (DSC)' : data);
				break;
			case 0xA301:	// SceneType (Exif IFD)
				output = 'Scene Type = ' + (data == '0x01,0x00,0x00,0x00' ? 'directly photographed image' : data);
				break;
			case 0xA302:	// CFAPattern (Exif IFD)
				// 1st 2 bytes = horizontal array length
				// 2nd 2 bytes = vertical array length
				// next bytes are the color values, row by row (123456 => Red/Green/Blue/Cyan/Magenta/Yellow/White)
				output = 'Color Filter Array (CFA) Geometric Pattern = ' + data;
				break;
			case 0xA401:	// CustomRendered (Exif IFD)
				var CustomRenders = new Array('normal process (0)', 'custom process (1)');
				output = 'Custom Rendered = ' + CustomRenders[data];
				break;
			case 0xA402:	// ExposureMode (Exif IFD)
				var ExposureModes = new Array('auto exposure (0)', 'manual exposure (1)', 'auto bracket (2)');
				output = 'Exposure Mode = ' + ExposureModes[data];
				break;
			case 0xA403:	// WhiteBalance (Exif IFD)
				var WhiteBalances = new Array('auto (0)', 'manual (1)');
				output = 'White Balance = ' + WhiteBalances[data];
				break; 
			case 0xA404:	// DigitalZoomRatio (Exif IFD)
				output = 'Digital Zoom Ratio = ' + data + ' = ' + formatRational(data, 2);
				break;
			case 0xA405:	// FocalLengthIn35mmFilm (Exif IFD)
				output = 'Focal Length in 35mm Film = ' + data;
				break;
			case 0xA406:	// SceneCaptureType (Exif IFD)
				var SceneCaptureTypes = new Array('standard (0)', 'landscape (1)', 'portrait (2)', 'night scene (3)');
				output = 'Scene Capture Type = ' + SceneCaptureTypes[data];
				break;
			case 0xA407:	// GainControl (Exif IFD)
				var GainControls = new Array('n/a', 'low gain up (1)', 'high gain up (2)', 
									'low gain down (3)', 'high gain down (4)');  
				output = 'Gain Control = ' + GainControls[data];
				break;
			case 0xA408:	// Contrast (Exif IFD)
				var Contrasts = new Array('normal (0)', 'soft (1)', 'hard (2)');
				output = 'Contrast = ' + Contrasts[data];
				break;
			case 0xA409:	// Saturation (Exif IFD)
				var Saturations = new Array('normal (0)', 'low (1)', 'high (2)');
				output = 'Saturation  = ' + Saturations[data];
				break;
			case 0xA40A:	// Sharpness (Exif IFD)
				var Sharpnesses = new Array('normal (0)', 'soft (1)', 'hard (2)');
				output = 'Sharpness = ' + Sharpnesses[data];
				break;
			case 0xA40B:	// DeviceSettingDescription (Exif IFD)
				// like 0xA302 
				output = 'Device Setting Description  = ' + data;
				break;
			case 0xA40C:	// SubjectDistanceRange (Exif IFD)
				var SubjectDistanceRanges = new Array('unknown (0)', 'macro (1)', 
						'close view (2)', 'distant view (3)');
				output = 'Subject Distance Range = ' + SubjectDistanceRanges[data];
				break;
			case 0xA420:	// ImageUniqueID (Exif IFD)
				output = 'Image Unique ID = ' + data;
				break;
			default:
				output = 'Unknown tag: Tagnum = 0x' + tagnum.toString(16) + '  ===>  data = ' + data;
				break;
			}
	return output; 
}	// getExifInterpretedTagData()

function getExifTagNumber(text) {
	var ExifTags = {
		"ImageWidth" : 					0x0100 ,
		"ImageLength" : 				0x0101 ,
		"BitsPerSample" : 				0x0102 ,
		"Compression" : 				0x0103 ,
		"PhotometricInterpretation" :	0x0106 ,
		"FillOrder" : 					0x010A ,
		"DocumentName" : 				0x010D ,
		"ImageDescription" : 			0x010E ,
		"Make" : 						0x010F ,
		"Model" : 						0x0110 ,
		"StripOffsets" : 				0x0111 ,
		"Orientation" : 				0x0112 ,
		"SamplesPerPixel" : 			0x0115 ,
		"RowsPerStrip" : 				0x0116 ,
		"StripByteCounts" : 			0x0117 ,
		"XResolution" : 				0x011A ,
		"YResolution" : 				0x011B ,
		"PlanarConfiguration" : 		0x011C ,
		"ResolutionUnit" : 				0x0128 ,
		"TransferFunction" : 			0x012D ,
		"Software" : 					0x0131 ,
		"DateTime" : 					0x0132 ,
		"Artist" : 						0x013B ,
		"WhitePoint" : 					0x013E ,
		"PrimaryChromaticities" : 		0x013F ,
		"TransferRange" : 				0x0156 ,
		"JPEGProc" : 					0x0200 ,
		"JPEGInterchangeFormat" : 		0x0201 ,
		"JPEGInterchangeFormatLength" : 0x0202 ,
		"YCbCrCoefficients" : 			0x0211 ,
		"YCbCrSubSampling" : 			0x0212 ,
		"YCbCrPositioning" : 			0x0213 ,
		"ReferenceBlackWhite" : 		0x0214 ,
		"BatteryLevel" : 				0x828F ,
		"Copyright" : 					0x8298 ,
		"ExposureTime" : 				0x829A ,
		"FNumber" : 					0x829D ,
		"IPTC/NAA" : 					0x83BB ,
		"ExifIFDPointer" : 				0x8769 ,
		"InterColorProfile" : 			0x8773 ,
		"ExposureProgram" : 			0x8822 ,
		"SpectralSensitivity" : 		0x8824 ,
		"GPSInfoIFDPointer" : 			0x8825 ,
		"ISOSpeedRatings" : 			0x8827 ,
		"OECF" : 						0x8828 ,
		"ExifVersion" : 				0x9000 ,
		"DateTimeOriginal" : 			0x9003 ,
		"DateTimeDigitized" : 			0x9004 ,
		"ComponentsConfiguration" : 	0x9101 ,
		"CompressedBitsPerPixel" : 		0x9102 ,
		"ShutterSpeedValue" : 			0x9201 ,
		"ApertureValue" : 				0x9202 ,
		"BrightnessValue" : 			0x9203 ,
		"ExposureBiasValue" : 			0x9204 ,
		"MaxApertureValue" : 			0x9205 ,
		"SubjectDistance" : 			0x9206 ,
		"MeteringMode" : 				0x9207 ,
		"LightSource" : 				0x9208 ,
		"Flash" : 						0x9209 ,
		"FocalLength" : 				0x920A ,
		"SubjectArea" : 				0x9214 ,
		"MakerNote" : 					0x927C ,
		"UserComment" : 				0x9286 ,
		"SubSecTime" : 					0x9290 ,
		"SubSecTimeOriginal" : 			0x9291 ,
		"SubSecTimeDigitized" : 		0x9292 ,
		"FlashPixVersion" : 			0xA000 ,
		"ColorSpace" : 					0xA001 ,
		"PixelXDimension" : 			0xA002 ,
		"PixelYDimension" : 			0xA003 ,
		"RelatedSoundFile" : 			0xA004 ,
		"InteroperabilityIFDPointer" : 	0xA005 ,
		"FlashEnergy" : 				0xA20B ,	// 0x920B in TIFF/EP
		"SpatialFrequencyResponse" :	0xA20C ,	// 0x920C    -  -
		"FocalPlaneXResolution" : 		0xA20E ,	// 0x920E    -  -
		"FocalPlaneYResolution" : 		0xA20F ,	// 0x920F    -  -
		"FocalPlaneResolutionUnit" : 	0xA210 ,	// 0x9210    -  -
		"SubjectLocation" : 			0xA214 ,	// 0x9214    -  -
		"ExposureIndex" : 				0xA215 ,	// 0x9215    -  -
		"SensingMethod" : 				0xA217 ,	// 0x9217    -  -
		"FileSource" : 					0xA300 ,
		"SceneType" : 					0xA301 ,
		"CFAPattern" : 					0xA302 ,	// 0x828E in TIFF/EP
		"CustomRendered" : 				0xA401 ,
		"ExposureMode" : 				0xA402 ,
		"WhiteBalance" : 				0xA403 ,
		"DigitalZoomRatio" : 			0xA404 ,
		"FocalLengthIn35mmFilm" : 		0xA405 ,
		"SceneCaptureType" : 			0xA406 ,
		"GainControl" : 				0xA407 ,
		"Contrast" : 					0xA408 ,
		"Saturation" : 					0xA409 ,
		"Sharpness" : 					0xA40A ,
		"DeviceSettingDescription" : 	0xA40B ,
		"SubjectDistanceRange" : 		0xA40C ,
		"ImageUniqueID" : 				0xA420
	};
	return ExifTags[text]; 
}	// getExifTagNumber()

function getExifIOPTagNumber(text) {
	var IOPTags = {
		"InteroperabilityIndex" : 	0x0001 ,
		"InteroperabilityVersion" :	0x0002 ,
		"RelatedImageFileFormat" : 	0x1000 ,
		"RelatedImageWidth" : 		0x1001 ,
		"RelatedImageLength" : 		0x1002
	};
	return IOPTags[text];
}	// getExifIOPTagNumber()

function getExifGPSTagNumber(text) {
	var GPSTags = {
		"GPSVersionID" : 0x0,
		"GPSLatitudeRef" : 		0x01 ,
		"GPSLatitude" : 		0x02 ,
		"GPSLongitudeRef" : 	0x03 ,
		"GPSLongitude" : 		0x04 ,
		"GPSAltitudeRef" : 		0x05 ,
		"GPSAltitude" : 		0x06 ,
		"GPSTimeStamp" : 		0x07 ,
		"GPSSatellites" : 		0x08 ,
		"GPSStatus" : 			0x09 ,
		"GPSMeasureMode" : 		0x0A ,
		"GPSDOP" : 				0x0B,
		"GPSSpeedRef" : 		0x0C ,
		"GPSSpeed" : 			0x0D ,
		"GPSTrackRef" : 		0x0E ,
		"GPSTrack" : 			0x0F ,
		"GPSImgDirectionRef" :	0x10 ,
		"GPSImgDirection" : 	0x11 ,
		"GPSMapDatum" : 		0x12 ,
		"GPSDestLatitudeRef" : 	0x13 ,
		"GPSDestLatitude" : 	0x14 ,
		"GPSDestLongitudeRef" :	0x15 ,
		"GPSDestLongitude" : 	0x16 ,
		"GPSDestBearingRef" : 	0x17 ,
		"GPSDestBearing" : 		0x18 ,
		"GPSDestDistanceRef" : 	0x19 ,
		"GPSDestDistance" : 	0x1A ,
		"GPSProcessingMethod" :	0x1B ,
		"GPSAreaInformation" : 	0x1C ,
		"GPSDateStamp" : 		0x1D ,
		"GPSDifferential" : 	0x1E 
	};
	return GPSTags[text];
}	// getExifGPSTagNumber()
